#### Please select the sections that you would like to print

Select All
Case Information
Party
Events and Hearings
Financial
Print

# Case Information

21D06499 | owner: VSPATL c/o SYLVAN HOMES LLC VS UNAUTHORIZED OCCUPANTS

Case Number
21D06499

Court
Division 0

Judicial Officer
Anderson, Berryl A

File Date
05/12/2021

Case Type
Magistrate Dispossessory - Tenant Holding Over

Case Status
Open

# Party

Respondant (Participant)
BRANTLEY, CHEKASHA

Address

1431 COBB BRANCH DR
DECATUR GA 30032

Plaintiff
owner: VSPATL c/o SYLVAN HOMES LLC

Address

3495 PIEDMONT ROAD, BDLG 11, SUTIE 302
ATLANTA GA 30305

Active Attorneys

Lead Attorney
Wilson, Lynn M.

Retained

Defendant
OCCUPANTS, UNAUTHORIZED

Address

1431 COVV BRANCH DR
DECATUR GA 30032

# Events and Hearings

- 05/12/2021 Dispossessory Warrant

- 05/26/2021 Answer and Counterclaim

- 05/28/2021 Affidavit of Service

  Comment
  ANS BY 5/27/2021

Loading financial, please wait...